@@ -53,7 +53,7 @@ class BaseElement(list):
         to be able to return non-string objects during rendering.
         """
         while isinstance(element, Lazy):
-            element = element.resolve(context, self)
+            element = element.resolve(context)
         if isinstance(element, BaseElement):
             yield from element.render(context)
         elif element is not None:
@@ -170,6 +170,9 @@ class BaseElement(list):
             treewalk(BaseElement(self), (), filter_func=filter_func, apply=delfunc)
         )
 
+    def replace(self, *args, **kwargs):
+        return self._replace(*args, **kwargs)
+
     # untested code
     def _replace(
         self, select_func: typing.Callable, replacement: BaseElement, all: bool = False
