@@ -1,6 +1,7 @@
 import typing
+import warnings
 
-from .base import BaseElement
+from .base import BaseElement, If
 from .lazy import Lazy, resolve_lazy
 
 
@@ -13,6 +14,10 @@ class HTMLElement(BaseElement):
         self, *children, lazy_attributes: typing.Optional[Lazy] = None, **attributes
     ):
         assert self.tag != ""
+        if any(attr == "class" for attr in attributes.keys()):
+            warnings.warn(
+                'You should use "_class" instead of "class" when specifiying HTML classes in htmlgenerator ("class" is a python keyword).'
+            )
         self.attributes: dict = attributes
         super().__init__(*children)
         if lazy_attributes and not isinstance(lazy_attributes, Lazy):
@@ -39,11 +44,9 @@ class HTMLElement(BaseElement):
     # mostly for debugging purposes
     def __repr__(self) -> str:
         return (
-            f"{self.__class__.__name__}("
-            + ", ".join(
-                [str(self.attributes), f"{len(self)} children"],
-            )
-            + ")"
+            f"<{self.tag} "
+            + " ".join(f"{k.lstrip('_')}=\"{v}\"" for k, v in self.attributes.items())
+            + f"> ({self.__class__})"
         )
 
 
@@ -679,10 +682,14 @@ def flatattrs(attributes: dict, context: dict, element: BaseElement) -> str:
     attlist = []
     for key, value in attributes.items():
         value = resolve_lazy(value, context, element)
-        if isinstance(value, BaseElement):
-            # in order to use e.g. an If element to disable the attribute
-            # we check whether the render result is empty
-            # (e.g. when we have only an If element which returns None in one branch)
+        if isinstance(value, If):
+            rendered = list(value.render(context, stringify=False))
+            if len(rendered) == 1 and isinstance(rendered[0], bool):
+                value = rendered[0]
+            else:
+                rendered = list(value.render(context))
+                value = "".join(rendered) if rendered else None
+        elif isinstance(value, BaseElement):
             rendered = list(value.render(context))
             value = "".join(rendered) if rendered else None
         if value is None:
@@ -697,3 +704,45 @@ def flatattrs(attributes: dict, context: dict, element: BaseElement) -> str:
         else:
             attlist.append(f'{key}="{value}"')
     return " ".join(attlist)
+
+
+def append_attribute(attrs, key, value, separator=None):
+    """
+    In many cases we want a component to add e.g. something to the
+    _class attribute of an HTML element but still allow the caller to
+    pass his own _class attribute to the component. In these cases
+    we can use ``append_attribute`` which will make sure that existing
+    attributes will not simply be overwritten.
+    Multiple items of attribute will in general require to be separated
+    by a separator. If the ``separator`` is not set, a best guess will be
+    done automatically.
+
+    Usage:
+
+        class MyDiv(hg.DIV):
+            def __init__(self, *args, **kwargs):
+                hg.append_attribute(kwargs, "_class", "mydiv")
+                super().__init__(*args, **kwargs)
+
+        a = MyDiv(_class="special-class")
+
+        assert a.attributes["_class"].split(" ") == ["special-class", mydiv]
+
+    """
+
+    def guess_separator(key):
+        default_separators = {
+            "_class": " ",
+            "style": ";",
+        }
+        if key in default_separators:
+            return default_separators[key]
+        # onclick and similar event handlers are javascript
+        if key.startswith("on") and key.islower() and key.isalpha():
+            return ";"
+        return " "
+
+    if key in attrs:
+        attrs[key] = BaseElement(attrs[key], separator or guess_separator(key), value)
+    else:
+        attrs[key] = value
